# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: schedule.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='schedule.proto',
  package='schedule',
  syntax='proto3',
  serialized_options=_b('\n\033com.supremainc.sdk.scheduleP\001Z\030biostar/service/schedule'),
  serialized_pb=_b('\n\x0eschedule.proto\x12\x08schedule\x1a\terr.proto\"\xa7\x01\n\x0cScheduleInfo\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12&\n\x05\x64\x61ily\x18\x03 \x01(\x0b\x32\x17.schedule.DailySchedule\x12(\n\x06weekly\x18\x04 \x01(\x0b\x32\x18.schedule.WeeklySchedule\x12+\n\x08holidays\x18\x05 \x03(\x0b\x32\x19.schedule.HolidaySchedule\"4\n\x0b\x44\x61ySchedule\x12%\n\x07periods\x18\x01 \x03(\x0b\x32\x14.schedule.TimePeriod\"0\n\nTimePeriod\x12\x11\n\tstartTime\x18\x01 \x01(\x05\x12\x0f\n\x07\x65ndTime\x18\x02 \x01(\x05\"=\n\x0eWeeklySchedule\x12+\n\x0c\x64\x61ySchedules\x18\x01 \x03(\x0b\x32\x15.schedule.DaySchedule\"O\n\rDailySchedule\x12\x11\n\tstartDate\x18\x01 \x01(\r\x12+\n\x0c\x64\x61ySchedules\x18\x02 \x03(\x0b\x32\x15.schedule.DaySchedule\"N\n\x0fHolidaySchedule\x12\x0f\n\x07groupID\x18\x01 \x01(\r\x12*\n\x0b\x64\x61ySchedule\x18\x02 \x01(\x0b\x32\x15.schedule.DaySchedule\"M\n\x0cHolidayGroup\x12\n\n\x02ID\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x08holidays\x18\x03 \x03(\x0b\x32\x11.schedule.Holiday\"H\n\x07Holiday\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\r\x12/\n\nrecurrence\x18\x02 \x01(\x0e\x32\x1b.schedule.HolidayRecurrence\"\"\n\x0eGetListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"<\n\x0fGetListResponse\x12)\n\tschedules\x18\x01 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"I\n\nAddRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12)\n\tschedules\x18\x02 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"\r\n\x0b\x41\x64\x64Response\"O\n\x0f\x41\x64\x64MultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12)\n\tschedules\x18\x02 \x03(\x0b\x32\x16.schedule.ScheduleInfo\"<\n\x10\x41\x64\x64MultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"6\n\rDeleteRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x13\n\x0bscheduleIDs\x18\x02 \x03(\r\"\x10\n\x0e\x44\x65leteResponse\"<\n\x12\x44\x65leteMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x13\n\x0bscheduleIDs\x18\x02 \x03(\r\"?\n\x13\x44\x65leteMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"$\n\x10\x44\x65leteAllRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x13\n\x11\x44\x65leteAllResponse\"*\n\x15\x44\x65leteAllMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"B\n\x16\x44\x65leteAllMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\")\n\x15GetHolidayListRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"@\n\x16GetHolidayListResponse\x12&\n\x06groups\x18\x01 \x03(\x0b\x32\x16.schedule.HolidayGroup\"M\n\x11\x41\x64\x64HolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12&\n\x06groups\x18\x02 \x03(\x0b\x32\x16.schedule.HolidayGroup\"\x14\n\x12\x41\x64\x64HolidayResponse\"S\n\x16\x41\x64\x64HolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12&\n\x06groups\x18\x02 \x03(\x0b\x32\x16.schedule.HolidayGroup\"C\n\x17\x41\x64\x64HolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\":\n\x14\x44\x65leteHolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"\x17\n\x15\x44\x65leteHolidayResponse\"@\n\x19\x44\x65leteHolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\x10\n\x08groupIDs\x18\x02 \x03(\r\"F\n\x1a\x44\x65leteHolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse\"+\n\x17\x44\x65leteAllHolidayRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"\x1a\n\x18\x44\x65leteAllHolidayResponse\"1\n\x1c\x44\x65leteAllHolidayMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\"I\n\x1d\x44\x65leteAllHolidayMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\\\n\x11HolidayRecurrence\x12\x10\n\x0c\x44O_NOT_RECUR\x10\x00\x12\x10\n\x0cRECUR_YEARLY\x10\x01\x12\x11\n\rRECUR_MONTHLY\x10\x02\x12\x10\n\x0cRECUR_WEEKLY\x10\x03\x32\xd3\x08\n\x08Schedule\x12>\n\x07GetList\x12\x18.schedule.GetListRequest\x1a\x19.schedule.GetListResponse\x12\x32\n\x03\x41\x64\x64\x12\x14.schedule.AddRequest\x1a\x15.schedule.AddResponse\x12\x41\n\x08\x41\x64\x64Multi\x12\x19.schedule.AddMultiRequest\x1a\x1a.schedule.AddMultiResponse\x12;\n\x06\x44\x65lete\x12\x17.schedule.DeleteRequest\x1a\x18.schedule.DeleteResponse\x12J\n\x0b\x44\x65leteMulti\x12\x1c.schedule.DeleteMultiRequest\x1a\x1d.schedule.DeleteMultiResponse\x12\x44\n\tDeleteAll\x12\x1a.schedule.DeleteAllRequest\x1a\x1b.schedule.DeleteAllResponse\x12S\n\x0e\x44\x65leteAllMulti\x12\x1f.schedule.DeleteAllMultiRequest\x1a .schedule.DeleteAllMultiResponse\x12S\n\x0eGetHolidayList\x12\x1f.schedule.GetHolidayListRequest\x1a .schedule.GetHolidayListResponse\x12G\n\nAddHoliday\x12\x1b.schedule.AddHolidayRequest\x1a\x1c.schedule.AddHolidayResponse\x12V\n\x0f\x41\x64\x64HolidayMulti\x12 .schedule.AddHolidayMultiRequest\x1a!.schedule.AddHolidayMultiResponse\x12P\n\rDeleteHoliday\x12\x1e.schedule.DeleteHolidayRequest\x1a\x1f.schedule.DeleteHolidayResponse\x12_\n\x12\x44\x65leteHolidayMulti\x12#.schedule.DeleteHolidayMultiRequest\x1a$.schedule.DeleteHolidayMultiResponse\x12Y\n\x10\x44\x65leteAllHoliday\x12!.schedule.DeleteAllHolidayRequest\x1a\".schedule.DeleteAllHolidayResponse\x12h\n\x15\x44\x65leteAllHolidayMulti\x12&.schedule.DeleteAllHolidayMultiRequest\x1a\'.schedule.DeleteAllHolidayMultiResponseB9\n\x1b\x63om.supremainc.sdk.scheduleP\x01Z\x18\x62iostar/service/scheduleb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_HOLIDAYRECURRENCE = _descriptor.EnumDescriptor(
  name='HolidayRecurrence',
  full_name='schedule.HolidayRecurrence',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DO_NOT_RECUR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_YEARLY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_MONTHLY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECUR_WEEKLY', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2179,
  serialized_end=2271,
)
_sym_db.RegisterEnumDescriptor(_HOLIDAYRECURRENCE)

HolidayRecurrence = enum_type_wrapper.EnumTypeWrapper(_HOLIDAYRECURRENCE)
DO_NOT_RECUR = 0
RECUR_YEARLY = 1
RECUR_MONTHLY = 2
RECUR_WEEKLY = 3



_SCHEDULEINFO = _descriptor.Descriptor(
  name='ScheduleInfo',
  full_name='schedule.ScheduleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='schedule.ScheduleInfo.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='schedule.ScheduleInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daily', full_name='schedule.ScheduleInfo.daily', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekly', full_name='schedule.ScheduleInfo.weekly', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='holidays', full_name='schedule.ScheduleInfo.holidays', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=207,
)


_DAYSCHEDULE = _descriptor.Descriptor(
  name='DaySchedule',
  full_name='schedule.DaySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='periods', full_name='schedule.DaySchedule.periods', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=261,
)


_TIMEPERIOD = _descriptor.Descriptor(
  name='TimePeriod',
  full_name='schedule.TimePeriod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTime', full_name='schedule.TimePeriod.startTime', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endTime', full_name='schedule.TimePeriod.endTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=311,
)


_WEEKLYSCHEDULE = _descriptor.Descriptor(
  name='WeeklySchedule',
  full_name='schedule.WeeklySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='daySchedules', full_name='schedule.WeeklySchedule.daySchedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=374,
)


_DAILYSCHEDULE = _descriptor.Descriptor(
  name='DailySchedule',
  full_name='schedule.DailySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startDate', full_name='schedule.DailySchedule.startDate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daySchedules', full_name='schedule.DailySchedule.daySchedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=455,
)


_HOLIDAYSCHEDULE = _descriptor.Descriptor(
  name='HolidaySchedule',
  full_name='schedule.HolidaySchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupID', full_name='schedule.HolidaySchedule.groupID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daySchedule', full_name='schedule.HolidaySchedule.daySchedule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=457,
  serialized_end=535,
)


_HOLIDAYGROUP = _descriptor.Descriptor(
  name='HolidayGroup',
  full_name='schedule.HolidayGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='schedule.HolidayGroup.ID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='schedule.HolidayGroup.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='holidays', full_name='schedule.HolidayGroup.holidays', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=614,
)


_HOLIDAY = _descriptor.Descriptor(
  name='Holiday',
  full_name='schedule.Holiday',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='schedule.Holiday.date', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recurrence', full_name='schedule.Holiday.recurrence', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=688,
)


_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='schedule.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.GetListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=690,
  serialized_end=724,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='schedule.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.GetListResponse.schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=786,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='schedule.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.AddRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.AddRequest.schedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=861,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='schedule.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=876,
)


_ADDMULTIREQUEST = _descriptor.Descriptor(
  name='AddMultiRequest',
  full_name='schedule.AddMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.AddMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedules', full_name='schedule.AddMultiRequest.schedules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=957,
)


_ADDMULTIRESPONSE = _descriptor.Descriptor(
  name='AddMultiResponse',
  full_name='schedule.AddMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.AddMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1019,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='schedule.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleIDs', full_name='schedule.DeleteRequest.scheduleIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1021,
  serialized_end=1075,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='schedule.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1093,
)


_DELETEMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteMultiRequest',
  full_name='schedule.DeleteMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduleIDs', full_name='schedule.DeleteMultiRequest.scheduleIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1155,
)


_DELETEMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteMultiResponse',
  full_name='schedule.DeleteMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1220,
)


_DELETEALLREQUEST = _descriptor.Descriptor(
  name='DeleteAllRequest',
  full_name='schedule.DeleteAllRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteAllRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1258,
)


_DELETEALLRESPONSE = _descriptor.Descriptor(
  name='DeleteAllResponse',
  full_name='schedule.DeleteAllResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1279,
)


_DELETEALLMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllMultiRequest',
  full_name='schedule.DeleteAllMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteAllMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1323,
)


_DELETEALLMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllMultiResponse',
  full_name='schedule.DeleteAllMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteAllMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1325,
  serialized_end=1391,
)


_GETHOLIDAYLISTREQUEST = _descriptor.Descriptor(
  name='GetHolidayListRequest',
  full_name='schedule.GetHolidayListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.GetHolidayListRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1393,
  serialized_end=1434,
)


_GETHOLIDAYLISTRESPONSE = _descriptor.Descriptor(
  name='GetHolidayListResponse',
  full_name='schedule.GetHolidayListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.GetHolidayListResponse.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1500,
)


_ADDHOLIDAYREQUEST = _descriptor.Descriptor(
  name='AddHolidayRequest',
  full_name='schedule.AddHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.AddHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.AddHolidayRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1579,
)


_ADDHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='AddHolidayResponse',
  full_name='schedule.AddHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1601,
)


_ADDHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='AddHolidayMultiRequest',
  full_name='schedule.AddHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.AddHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='schedule.AddHolidayMultiRequest.groups', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1603,
  serialized_end=1686,
)


_ADDHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='AddHolidayMultiResponse',
  full_name='schedule.AddHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.AddHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1688,
  serialized_end=1755,
)


_DELETEHOLIDAYREQUEST = _descriptor.Descriptor(
  name='DeleteHolidayRequest',
  full_name='schedule.DeleteHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='schedule.DeleteHolidayRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1815,
)


_DELETEHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='DeleteHolidayResponse',
  full_name='schedule.DeleteHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1817,
  serialized_end=1840,
)


_DELETEHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteHolidayMultiRequest',
  full_name='schedule.DeleteHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupIDs', full_name='schedule.DeleteHolidayMultiRequest.groupIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1906,
)


_DELETEHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteHolidayMultiResponse',
  full_name='schedule.DeleteHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1908,
  serialized_end=1978,
)


_DELETEALLHOLIDAYREQUEST = _descriptor.Descriptor(
  name='DeleteAllHolidayRequest',
  full_name='schedule.DeleteAllHolidayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='schedule.DeleteAllHolidayRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1980,
  serialized_end=2023,
)


_DELETEALLHOLIDAYRESPONSE = _descriptor.Descriptor(
  name='DeleteAllHolidayResponse',
  full_name='schedule.DeleteAllHolidayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2051,
)


_DELETEALLHOLIDAYMULTIREQUEST = _descriptor.Descriptor(
  name='DeleteAllHolidayMultiRequest',
  full_name='schedule.DeleteAllHolidayMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='schedule.DeleteAllHolidayMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2102,
)


_DELETEALLHOLIDAYMULTIRESPONSE = _descriptor.Descriptor(
  name='DeleteAllHolidayMultiResponse',
  full_name='schedule.DeleteAllHolidayMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='schedule.DeleteAllHolidayMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2104,
  serialized_end=2177,
)

_SCHEDULEINFO.fields_by_name['daily'].message_type = _DAILYSCHEDULE
_SCHEDULEINFO.fields_by_name['weekly'].message_type = _WEEKLYSCHEDULE
_SCHEDULEINFO.fields_by_name['holidays'].message_type = _HOLIDAYSCHEDULE
_DAYSCHEDULE.fields_by_name['periods'].message_type = _TIMEPERIOD
_WEEKLYSCHEDULE.fields_by_name['daySchedules'].message_type = _DAYSCHEDULE
_DAILYSCHEDULE.fields_by_name['daySchedules'].message_type = _DAYSCHEDULE
_HOLIDAYSCHEDULE.fields_by_name['daySchedule'].message_type = _DAYSCHEDULE
_HOLIDAYGROUP.fields_by_name['holidays'].message_type = _HOLIDAY
_HOLIDAY.fields_by_name['recurrence'].enum_type = _HOLIDAYRECURRENCE
_GETLISTRESPONSE.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDREQUEST.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDMULTIREQUEST.fields_by_name['schedules'].message_type = _SCHEDULEINFO
_ADDMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_GETHOLIDAYLISTRESPONSE.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYREQUEST.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYMULTIREQUEST.fields_by_name['groups'].message_type = _HOLIDAYGROUP
_ADDHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
_DELETEALLHOLIDAYMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['ScheduleInfo'] = _SCHEDULEINFO
DESCRIPTOR.message_types_by_name['DaySchedule'] = _DAYSCHEDULE
DESCRIPTOR.message_types_by_name['TimePeriod'] = _TIMEPERIOD
DESCRIPTOR.message_types_by_name['WeeklySchedule'] = _WEEKLYSCHEDULE
DESCRIPTOR.message_types_by_name['DailySchedule'] = _DAILYSCHEDULE
DESCRIPTOR.message_types_by_name['HolidaySchedule'] = _HOLIDAYSCHEDULE
DESCRIPTOR.message_types_by_name['HolidayGroup'] = _HOLIDAYGROUP
DESCRIPTOR.message_types_by_name['Holiday'] = _HOLIDAY
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['AddMultiRequest'] = _ADDMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddMultiResponse'] = _ADDMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['DeleteMultiRequest'] = _DELETEMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteMultiResponse'] = _DELETEMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllRequest'] = _DELETEALLREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllResponse'] = _DELETEALLRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllMultiRequest'] = _DELETEALLMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllMultiResponse'] = _DELETEALLMULTIRESPONSE
DESCRIPTOR.message_types_by_name['GetHolidayListRequest'] = _GETHOLIDAYLISTREQUEST
DESCRIPTOR.message_types_by_name['GetHolidayListResponse'] = _GETHOLIDAYLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddHolidayRequest'] = _ADDHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['AddHolidayResponse'] = _ADDHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['AddHolidayMultiRequest'] = _ADDHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['AddHolidayMultiResponse'] = _ADDHOLIDAYMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteHolidayRequest'] = _DELETEHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteHolidayResponse'] = _DELETEHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteHolidayMultiRequest'] = _DELETEHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteHolidayMultiResponse'] = _DELETEHOLIDAYMULTIRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllHolidayRequest'] = _DELETEALLHOLIDAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllHolidayResponse'] = _DELETEALLHOLIDAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAllHolidayMultiRequest'] = _DELETEALLHOLIDAYMULTIREQUEST
DESCRIPTOR.message_types_by_name['DeleteAllHolidayMultiResponse'] = _DELETEALLHOLIDAYMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['HolidayRecurrence'] = _HOLIDAYRECURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScheduleInfo = _reflection.GeneratedProtocolMessageType('ScheduleInfo', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULEINFO,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.ScheduleInfo)
  ))
_sym_db.RegisterMessage(ScheduleInfo)

DaySchedule = _reflection.GeneratedProtocolMessageType('DaySchedule', (_message.Message,), dict(
  DESCRIPTOR = _DAYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DaySchedule)
  ))
_sym_db.RegisterMessage(DaySchedule)

TimePeriod = _reflection.GeneratedProtocolMessageType('TimePeriod', (_message.Message,), dict(
  DESCRIPTOR = _TIMEPERIOD,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.TimePeriod)
  ))
_sym_db.RegisterMessage(TimePeriod)

WeeklySchedule = _reflection.GeneratedProtocolMessageType('WeeklySchedule', (_message.Message,), dict(
  DESCRIPTOR = _WEEKLYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.WeeklySchedule)
  ))
_sym_db.RegisterMessage(WeeklySchedule)

DailySchedule = _reflection.GeneratedProtocolMessageType('DailySchedule', (_message.Message,), dict(
  DESCRIPTOR = _DAILYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DailySchedule)
  ))
_sym_db.RegisterMessage(DailySchedule)

HolidaySchedule = _reflection.GeneratedProtocolMessageType('HolidaySchedule', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAYSCHEDULE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.HolidaySchedule)
  ))
_sym_db.RegisterMessage(HolidaySchedule)

HolidayGroup = _reflection.GeneratedProtocolMessageType('HolidayGroup', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAYGROUP,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.HolidayGroup)
  ))
_sym_db.RegisterMessage(HolidayGroup)

Holiday = _reflection.GeneratedProtocolMessageType('Holiday', (_message.Message,), dict(
  DESCRIPTOR = _HOLIDAY,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.Holiday)
  ))
_sym_db.RegisterMessage(Holiday)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

AddMultiRequest = _reflection.GeneratedProtocolMessageType('AddMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddMultiRequest)
  ))
_sym_db.RegisterMessage(AddMultiRequest)

AddMultiResponse = _reflection.GeneratedProtocolMessageType('AddMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddMultiResponse)
  ))
_sym_db.RegisterMessage(AddMultiResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

DeleteMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteMultiRequest)

DeleteMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteMultiResponse)

DeleteAllRequest = _reflection.GeneratedProtocolMessageType('DeleteAllRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllRequest)
  ))
_sym_db.RegisterMessage(DeleteAllRequest)

DeleteAllResponse = _reflection.GeneratedProtocolMessageType('DeleteAllResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllResponse)
  ))
_sym_db.RegisterMessage(DeleteAllResponse)

DeleteAllMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllMultiRequest)

DeleteAllMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllMultiResponse)

GetHolidayListRequest = _reflection.GeneratedProtocolMessageType('GetHolidayListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETHOLIDAYLISTREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetHolidayListRequest)
  ))
_sym_db.RegisterMessage(GetHolidayListRequest)

GetHolidayListResponse = _reflection.GeneratedProtocolMessageType('GetHolidayListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETHOLIDAYLISTRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.GetHolidayListResponse)
  ))
_sym_db.RegisterMessage(GetHolidayListResponse)

AddHolidayRequest = _reflection.GeneratedProtocolMessageType('AddHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayRequest)
  ))
_sym_db.RegisterMessage(AddHolidayRequest)

AddHolidayResponse = _reflection.GeneratedProtocolMessageType('AddHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayResponse)
  ))
_sym_db.RegisterMessage(AddHolidayResponse)

AddHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('AddHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(AddHolidayMultiRequest)

AddHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('AddHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.AddHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(AddHolidayMultiResponse)

DeleteHolidayRequest = _reflection.GeneratedProtocolMessageType('DeleteHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayRequest)
  ))
_sym_db.RegisterMessage(DeleteHolidayRequest)

DeleteHolidayResponse = _reflection.GeneratedProtocolMessageType('DeleteHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayResponse)
  ))
_sym_db.RegisterMessage(DeleteHolidayResponse)

DeleteHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteHolidayMultiRequest)

DeleteHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteHolidayMultiResponse)

DeleteAllHolidayRequest = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayRequest)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayRequest)

DeleteAllHolidayResponse = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayResponse)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayResponse)

DeleteAllHolidayMultiRequest = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYMULTIREQUEST,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayMultiRequest)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayMultiRequest)

DeleteAllHolidayMultiResponse = _reflection.GeneratedProtocolMessageType('DeleteAllHolidayMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEALLHOLIDAYMULTIRESPONSE,
  __module__ = 'schedule_pb2'
  # @@protoc_insertion_point(class_scope:schedule.DeleteAllHolidayMultiResponse)
  ))
_sym_db.RegisterMessage(DeleteAllHolidayMultiResponse)


DESCRIPTOR._options = None

_SCHEDULE = _descriptor.ServiceDescriptor(
  name='Schedule',
  full_name='schedule.Schedule',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2274,
  serialized_end=3381,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='schedule.Schedule.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='schedule.Schedule.Add',
    index=1,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddMulti',
    full_name='schedule.Schedule.AddMulti',
    index=2,
    containing_service=None,
    input_type=_ADDMULTIREQUEST,
    output_type=_ADDMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='schedule.Schedule.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMulti',
    full_name='schedule.Schedule.DeleteMulti',
    index=4,
    containing_service=None,
    input_type=_DELETEMULTIREQUEST,
    output_type=_DELETEMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='schedule.Schedule.DeleteAll',
    index=5,
    containing_service=None,
    input_type=_DELETEALLREQUEST,
    output_type=_DELETEALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllMulti',
    full_name='schedule.Schedule.DeleteAllMulti',
    index=6,
    containing_service=None,
    input_type=_DELETEALLMULTIREQUEST,
    output_type=_DELETEALLMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetHolidayList',
    full_name='schedule.Schedule.GetHolidayList',
    index=7,
    containing_service=None,
    input_type=_GETHOLIDAYLISTREQUEST,
    output_type=_GETHOLIDAYLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddHoliday',
    full_name='schedule.Schedule.AddHoliday',
    index=8,
    containing_service=None,
    input_type=_ADDHOLIDAYREQUEST,
    output_type=_ADDHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddHolidayMulti',
    full_name='schedule.Schedule.AddHolidayMulti',
    index=9,
    containing_service=None,
    input_type=_ADDHOLIDAYMULTIREQUEST,
    output_type=_ADDHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHoliday',
    full_name='schedule.Schedule.DeleteHoliday',
    index=10,
    containing_service=None,
    input_type=_DELETEHOLIDAYREQUEST,
    output_type=_DELETEHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteHolidayMulti',
    full_name='schedule.Schedule.DeleteHolidayMulti',
    index=11,
    containing_service=None,
    input_type=_DELETEHOLIDAYMULTIREQUEST,
    output_type=_DELETEHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllHoliday',
    full_name='schedule.Schedule.DeleteAllHoliday',
    index=12,
    containing_service=None,
    input_type=_DELETEALLHOLIDAYREQUEST,
    output_type=_DELETEALLHOLIDAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAllHolidayMulti',
    full_name='schedule.Schedule.DeleteAllHolidayMulti',
    index=13,
    containing_service=None,
    input_type=_DELETEALLHOLIDAYMULTIREQUEST,
    output_type=_DELETEALLHOLIDAYMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SCHEDULE)

DESCRIPTOR.services_by_name['Schedule'] = _SCHEDULE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import connect_pb2 as connect__pb2


class ConnectStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Connect = channel.unary_unary(
        '/connect.Connect/Connect',
        request_serializer=connect__pb2.ConnectRequest.SerializeToString,
        response_deserializer=connect__pb2.ConnectResponse.FromString,
        )
    self.AddAsyncConnection = channel.unary_unary(
        '/connect.Connect/AddAsyncConnection',
        request_serializer=connect__pb2.AddAsyncConnectionRequest.SerializeToString,
        response_deserializer=connect__pb2.AddAsyncConnectionResponse.FromString,
        )
    self.DeleteAsyncConnection = channel.unary_unary(
        '/connect.Connect/DeleteAsyncConnection',
        request_serializer=connect__pb2.DeleteAsyncConnectionRequest.SerializeToString,
        response_deserializer=connect__pb2.DeleteAsyncConnectionResponse.FromString,
        )
    self.SetAcceptFilter = channel.unary_unary(
        '/connect.Connect/SetAcceptFilter',
        request_serializer=connect__pb2.SetAcceptFilterRequest.SerializeToString,
        response_deserializer=connect__pb2.SetAcceptFilterResponse.FromString,
        )
    self.GetAcceptFilter = channel.unary_unary(
        '/connect.Connect/GetAcceptFilter',
        request_serializer=connect__pb2.GetAcceptFilterRequest.SerializeToString,
        response_deserializer=connect__pb2.GetAcceptFilterResponse.FromString,
        )
    self.GetPendingList = channel.unary_unary(
        '/connect.Connect/GetPendingList',
        request_serializer=connect__pb2.GetPendingListRequest.SerializeToString,
        response_deserializer=connect__pb2.GetPendingListResponse.FromString,
        )
    self.GetDeviceList = channel.unary_unary(
        '/connect.Connect/GetDeviceList',
        request_serializer=connect__pb2.GetDeviceListRequest.SerializeToString,
        response_deserializer=connect__pb2.GetDeviceListResponse.FromString,
        )
    self.Disconnect = channel.unary_unary(
        '/connect.Connect/Disconnect',
        request_serializer=connect__pb2.DisconnectRequest.SerializeToString,
        response_deserializer=connect__pb2.DisconnectResponse.FromString,
        )
    self.DisconnectAll = channel.unary_unary(
        '/connect.Connect/DisconnectAll',
        request_serializer=connect__pb2.DisconnectAllRequest.SerializeToString,
        response_deserializer=connect__pb2.DisconnectAllResponse.FromString,
        )
    self.SearchDevice = channel.unary_unary(
        '/connect.Connect/SearchDevice',
        request_serializer=connect__pb2.SearchDeviceRequest.SerializeToString,
        response_deserializer=connect__pb2.SearchDeviceResponse.FromString,
        )
    self.GetSlaveDevice = channel.unary_unary(
        '/connect.Connect/GetSlaveDevice',
        request_serializer=connect__pb2.GetSlaveDeviceRequest.SerializeToString,
        response_deserializer=connect__pb2.GetSlaveDeviceResponse.FromString,
        )
    self.SetSlaveDevice = channel.unary_unary(
        '/connect.Connect/SetSlaveDevice',
        request_serializer=connect__pb2.SetSlaveDeviceRequest.SerializeToString,
        response_deserializer=connect__pb2.SetSlaveDeviceResponse.FromString,
        )
    self.SetConnectionMode = channel.unary_unary(
        '/connect.Connect/SetConnectionMode',
        request_serializer=connect__pb2.SetConnectionModeRequest.SerializeToString,
        response_deserializer=connect__pb2.SetConnectionModeResponse.FromString,
        )
    self.SetConnectionModeMulti = channel.unary_unary(
        '/connect.Connect/SetConnectionModeMulti',
        request_serializer=connect__pb2.SetConnectionModeMultiRequest.SerializeToString,
        response_deserializer=connect__pb2.SetConnectionModeMultiResponse.FromString,
        )
    self.EnableSSL = channel.unary_unary(
        '/connect.Connect/EnableSSL',
        request_serializer=connect__pb2.EnableSSLRequest.SerializeToString,
        response_deserializer=connect__pb2.EnableSSLResponse.FromString,
        )
    self.EnableSSLMulti = channel.unary_unary(
        '/connect.Connect/EnableSSLMulti',
        request_serializer=connect__pb2.EnableSSLMultiRequest.SerializeToString,
        response_deserializer=connect__pb2.EnableSSLMultiResponse.FromString,
        )
    self.DisableSSL = channel.unary_unary(
        '/connect.Connect/DisableSSL',
        request_serializer=connect__pb2.DisableSSLRequest.SerializeToString,
        response_deserializer=connect__pb2.DisableSSLResponse.FromString,
        )
    self.DisableSSLMulti = channel.unary_unary(
        '/connect.Connect/DisableSSLMulti',
        request_serializer=connect__pb2.DisableSSLMultiRequest.SerializeToString,
        response_deserializer=connect__pb2.DisableSSLMultiResponse.FromString,
        )
    self.SubscribeStatus = channel.unary_stream(
        '/connect.Connect/SubscribeStatus',
        request_serializer=connect__pb2.SubscribeStatusRequest.SerializeToString,
        response_deserializer=connect__pb2.StatusChange.FromString,
        )


class ConnectServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Connect(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddAsyncConnection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAsyncConnection(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetAcceptFilter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAcceptFilter(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetPendingList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDeviceList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Disconnect(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DisconnectAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SearchDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSlaveDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetSlaveDevice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConnectionMode(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConnectionModeMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EnableSSL(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EnableSSLMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DisableSSL(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DisableSSLMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubscribeStatus(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ConnectServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Connect': grpc.unary_unary_rpc_method_handler(
          servicer.Connect,
          request_deserializer=connect__pb2.ConnectRequest.FromString,
          response_serializer=connect__pb2.ConnectResponse.SerializeToString,
      ),
      'AddAsyncConnection': grpc.unary_unary_rpc_method_handler(
          servicer.AddAsyncConnection,
          request_deserializer=connect__pb2.AddAsyncConnectionRequest.FromString,
          response_serializer=connect__pb2.AddAsyncConnectionResponse.SerializeToString,
      ),
      'DeleteAsyncConnection': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAsyncConnection,
          request_deserializer=connect__pb2.DeleteAsyncConnectionRequest.FromString,
          response_serializer=connect__pb2.DeleteAsyncConnectionResponse.SerializeToString,
      ),
      'SetAcceptFilter': grpc.unary_unary_rpc_method_handler(
          servicer.SetAcceptFilter,
          request_deserializer=connect__pb2.SetAcceptFilterRequest.FromString,
          response_serializer=connect__pb2.SetAcceptFilterResponse.SerializeToString,
      ),
      'GetAcceptFilter': grpc.unary_unary_rpc_method_handler(
          servicer.GetAcceptFilter,
          request_deserializer=connect__pb2.GetAcceptFilterRequest.FromString,
          response_serializer=connect__pb2.GetAcceptFilterResponse.SerializeToString,
      ),
      'GetPendingList': grpc.unary_unary_rpc_method_handler(
          servicer.GetPendingList,
          request_deserializer=connect__pb2.GetPendingListRequest.FromString,
          response_serializer=connect__pb2.GetPendingListResponse.SerializeToString,
      ),
      'GetDeviceList': grpc.unary_unary_rpc_method_handler(
          servicer.GetDeviceList,
          request_deserializer=connect__pb2.GetDeviceListRequest.FromString,
          response_serializer=connect__pb2.GetDeviceListResponse.SerializeToString,
      ),
      'Disconnect': grpc.unary_unary_rpc_method_handler(
          servicer.Disconnect,
          request_deserializer=connect__pb2.DisconnectRequest.FromString,
          response_serializer=connect__pb2.DisconnectResponse.SerializeToString,
      ),
      'DisconnectAll': grpc.unary_unary_rpc_method_handler(
          servicer.DisconnectAll,
          request_deserializer=connect__pb2.DisconnectAllRequest.FromString,
          response_serializer=connect__pb2.DisconnectAllResponse.SerializeToString,
      ),
      'SearchDevice': grpc.unary_unary_rpc_method_handler(
          servicer.SearchDevice,
          request_deserializer=connect__pb2.SearchDeviceRequest.FromString,
          response_serializer=connect__pb2.SearchDeviceResponse.SerializeToString,
      ),
      'GetSlaveDevice': grpc.unary_unary_rpc_method_handler(
          servicer.GetSlaveDevice,
          request_deserializer=connect__pb2.GetSlaveDeviceRequest.FromString,
          response_serializer=connect__pb2.GetSlaveDeviceResponse.SerializeToString,
      ),
      'SetSlaveDevice': grpc.unary_unary_rpc_method_handler(
          servicer.SetSlaveDevice,
          request_deserializer=connect__pb2.SetSlaveDeviceRequest.FromString,
          response_serializer=connect__pb2.SetSlaveDeviceResponse.SerializeToString,
      ),
      'SetConnectionMode': grpc.unary_unary_rpc_method_handler(
          servicer.SetConnectionMode,
          request_deserializer=connect__pb2.SetConnectionModeRequest.FromString,
          response_serializer=connect__pb2.SetConnectionModeResponse.SerializeToString,
      ),
      'SetConnectionModeMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConnectionModeMulti,
          request_deserializer=connect__pb2.SetConnectionModeMultiRequest.FromString,
          response_serializer=connect__pb2.SetConnectionModeMultiResponse.SerializeToString,
      ),
      'EnableSSL': grpc.unary_unary_rpc_method_handler(
          servicer.EnableSSL,
          request_deserializer=connect__pb2.EnableSSLRequest.FromString,
          response_serializer=connect__pb2.EnableSSLResponse.SerializeToString,
      ),
      'EnableSSLMulti': grpc.unary_unary_rpc_method_handler(
          servicer.EnableSSLMulti,
          request_deserializer=connect__pb2.EnableSSLMultiRequest.FromString,
          response_serializer=connect__pb2.EnableSSLMultiResponse.SerializeToString,
      ),
      'DisableSSL': grpc.unary_unary_rpc_method_handler(
          servicer.DisableSSL,
          request_deserializer=connect__pb2.DisableSSLRequest.FromString,
          response_serializer=connect__pb2.DisableSSLResponse.SerializeToString,
      ),
      'DisableSSLMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DisableSSLMulti,
          request_deserializer=connect__pb2.DisableSSLMultiRequest.FromString,
          response_serializer=connect__pb2.DisableSSLMultiResponse.SerializeToString,
      ),
      'SubscribeStatus': grpc.unary_stream_rpc_method_handler(
          servicer.SubscribeStatus,
          request_deserializer=connect__pb2.SubscribeStatusRequest.FromString,
          response_serializer=connect__pb2.StatusChange.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'connect.Connect', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tenant.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import cert_pb2 as cert__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tenant.proto',
  package='tenant',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.tenantP\001Z\026biostar/service/tenant'),
  serialized_pb=_b('\n\x0ctenant.proto\x12\x06tenant\x1a\ncert.proto\"2\n\nTenantInfo\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x10\n\x0eGetListRequest\"$\n\x0fGetListResponse\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x1f\n\nGetRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"6\n\x0bGetResponse\x12\'\n\x0btenantInfos\x18\x01 \x03(\x0b\x32\x12.tenant.TenantInfo\"5\n\nAddRequest\x12\'\n\x0btenantInfos\x18\x01 \x03(\x0b\x32\x12.tenant.TenantInfo\"\r\n\x0b\x41\x64\x64Response\"\"\n\rDeleteRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x10\n\x0e\x44\x65leteResponse\"9\n\x11\x41\x64\x64GatewayRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x14\n\x12\x41\x64\x64GatewayResponse\"<\n\x14\x44\x65leteGatewayRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x12\n\ngatewayIDs\x18\x02 \x03(\t\"\x17\n\x15\x44\x65leteGatewayResponse\"f\n\x18\x43reateCertificateRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x18\n\x10\x65xpireAfterYears\x18\x03 \x01(\x05\"B\n\x19\x43reateCertificateResponse\x12\x12\n\ntenantCert\x18\x01 \x01(\t\x12\x11\n\ttenantKey\x18\x02 \x01(\t\".\n\x19GetIssuanceHistoryRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"\x91\x01\n\x0f\x43\x65rtificateInfo\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x10\n\x08serialNO\x18\x03 \x01(\x03\x12\x11\n\tissueDate\x18\x04 \x01(\x03\x12\x12\n\nexpiryDate\x18\x05 \x01(\x03\x12\x13\n\x0b\x62lacklisted\x18\x06 \x01(\x08\"H\n\x1aGetIssuanceHistoryResponse\x12*\n\tcertInfos\x18\x01 \x03(\x0b\x32\x17.tenant.CertificateInfo\"3\n\x1eGetCertificateBlacklistRequest\x12\x11\n\ttenantIDs\x18\x01 \x03(\t\"M\n\x1fGetCertificateBlacklistResponse\x12*\n\tcertInfos\x18\x01 \x03(\x0b\x32\x17.tenant.CertificateInfo\"E\n\x1e\x41\x64\x64\x43\x65rtificateBlacklistRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"!\n\x1f\x41\x64\x64\x43\x65rtificateBlacklistResponse\"H\n!DeleteCertificateBlacklistRequest\x12\x10\n\x08tenantID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"$\n\"DeleteCertificateBlacklistResponse2\xf4\x06\n\x06Tenant\x12:\n\x07GetList\x12\x16.tenant.GetListRequest\x1a\x17.tenant.GetListResponse\x12.\n\x03Get\x12\x12.tenant.GetRequest\x1a\x13.tenant.GetResponse\x12.\n\x03\x41\x64\x64\x12\x12.tenant.AddRequest\x1a\x13.tenant.AddResponse\x12\x37\n\x06\x44\x65lete\x12\x15.tenant.DeleteRequest\x1a\x16.tenant.DeleteResponse\x12\x43\n\nAddGateway\x12\x19.tenant.AddGatewayRequest\x1a\x1a.tenant.AddGatewayResponse\x12L\n\rDeleteGateway\x12\x1c.tenant.DeleteGatewayRequest\x1a\x1d.tenant.DeleteGatewayResponse\x12X\n\x11\x43reateCertificate\x12 .tenant.CreateCertificateRequest\x1a!.tenant.CreateCertificateResponse\x12[\n\x12GetIssuanceHistory\x12!.tenant.GetIssuanceHistoryRequest\x1a\".tenant.GetIssuanceHistoryResponse\x12j\n\x17GetCertificateBlacklist\x12&.tenant.GetCertificateBlacklistRequest\x1a\'.tenant.GetCertificateBlacklistResponse\x12j\n\x17\x41\x64\x64\x43\x65rtificateBlacklist\x12&.tenant.AddCertificateBlacklistRequest\x1a\'.tenant.AddCertificateBlacklistResponse\x12s\n\x1a\x44\x65leteCertificateBlacklist\x12).tenant.DeleteCertificateBlacklistRequest\x1a*.tenant.DeleteCertificateBlacklistResponseB5\n\x19\x63om.supremainc.sdk.tenantP\x01Z\x16\x62iostar/service/tenantb\x06proto3')
  ,
  dependencies=[cert__pb2.DESCRIPTOR,])




_TENANTINFO = _descriptor.Descriptor(
  name='TenantInfo',
  full_name='tenant.TenantInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.TenantInfo.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.TenantInfo.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=86,
)


_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='tenant.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=104,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='tenant.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetListResponse.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=142,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='tenant.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=175,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='tenant.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantInfos', full_name='tenant.GetResponse.tenantInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=231,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='tenant.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantInfos', full_name='tenant.AddRequest.tenantInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=286,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='tenant.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=301,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='tenant.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.DeleteRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=337,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='tenant.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=355,
)


_ADDGATEWAYREQUEST = _descriptor.Descriptor(
  name='AddGatewayRequest',
  full_name='tenant.AddGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.AddGatewayRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.AddGatewayRequest.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=414,
)


_ADDGATEWAYRESPONSE = _descriptor.Descriptor(
  name='AddGatewayResponse',
  full_name='tenant.AddGatewayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=436,
)


_DELETEGATEWAYREQUEST = _descriptor.Descriptor(
  name='DeleteGatewayRequest',
  full_name='tenant.DeleteGatewayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.DeleteGatewayRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='tenant.DeleteGatewayRequest.gatewayIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=498,
)


_DELETEGATEWAYRESPONSE = _descriptor.Descriptor(
  name='DeleteGatewayResponse',
  full_name='tenant.DeleteGatewayResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=523,
)


_CREATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateCertificateRequest',
  full_name='tenant.CreateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.CreateCertificateRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='tenant.CreateCertificateRequest.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expireAfterYears', full_name='tenant.CreateCertificateRequest.expireAfterYears', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=627,
)


_CREATECERTIFICATERESPONSE = _descriptor.Descriptor(
  name='CreateCertificateResponse',
  full_name='tenant.CreateCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantCert', full_name='tenant.CreateCertificateResponse.tenantCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tenantKey', full_name='tenant.CreateCertificateResponse.tenantKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=695,
)


_GETISSUANCEHISTORYREQUEST = _descriptor.Descriptor(
  name='GetIssuanceHistoryRequest',
  full_name='tenant.GetIssuanceHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetIssuanceHistoryRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=743,
)


_CERTIFICATEINFO = _descriptor.Descriptor(
  name='CertificateInfo',
  full_name='tenant.CertificateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.CertificateInfo.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='tenant.CertificateInfo.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNO', full_name='tenant.CertificateInfo.serialNO', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueDate', full_name='tenant.CertificateInfo.issueDate', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiryDate', full_name='tenant.CertificateInfo.expiryDate', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='tenant.CertificateInfo.blacklisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=891,
)


_GETISSUANCEHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetIssuanceHistoryResponse',
  full_name='tenant.GetIssuanceHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='tenant.GetIssuanceHistoryResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=965,
)


_GETCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='GetCertificateBlacklistRequest',
  full_name='tenant.GetCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantIDs', full_name='tenant.GetCertificateBlacklistRequest.tenantIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=967,
  serialized_end=1018,
)


_GETCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='GetCertificateBlacklistResponse',
  full_name='tenant.GetCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='tenant.GetCertificateBlacklistResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1097,
)


_ADDCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='AddCertificateBlacklistRequest',
  full_name='tenant.AddCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.AddCertificateBlacklistRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='tenant.AddCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1168,
)


_ADDCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='AddCertificateBlacklistResponse',
  full_name='tenant.AddCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1203,
)


_DELETECERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistRequest',
  full_name='tenant.DeleteCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tenantID', full_name='tenant.DeleteCertificateBlacklistRequest.tenantID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='tenant.DeleteCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1277,
)


_DELETECERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistResponse',
  full_name='tenant.DeleteCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1279,
  serialized_end=1315,
)

_GETRESPONSE.fields_by_name['tenantInfos'].message_type = _TENANTINFO
_ADDREQUEST.fields_by_name['tenantInfos'].message_type = _TENANTINFO
_CREATECERTIFICATEREQUEST.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_CERTIFICATEINFO.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_GETISSUANCEHISTORYRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
_GETCERTIFICATEBLACKLISTRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
DESCRIPTOR.message_types_by_name['TenantInfo'] = _TENANTINFO
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['AddGatewayRequest'] = _ADDGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['AddGatewayResponse'] = _ADDGATEWAYRESPONSE
DESCRIPTOR.message_types_by_name['DeleteGatewayRequest'] = _DELETEGATEWAYREQUEST
DESCRIPTOR.message_types_by_name['DeleteGatewayResponse'] = _DELETEGATEWAYRESPONSE
DESCRIPTOR.message_types_by_name['CreateCertificateRequest'] = _CREATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateCertificateResponse'] = _CREATECERTIFICATERESPONSE
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryRequest'] = _GETISSUANCEHISTORYREQUEST
DESCRIPTOR.message_types_by_name['CertificateInfo'] = _CERTIFICATEINFO
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryResponse'] = _GETISSUANCEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistRequest'] = _GETCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistResponse'] = _GETCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistRequest'] = _ADDCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistResponse'] = _ADDCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistRequest'] = _DELETECERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistResponse'] = _DELETECERTIFICATEBLACKLISTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TenantInfo = _reflection.GeneratedProtocolMessageType('TenantInfo', (_message.Message,), dict(
  DESCRIPTOR = _TENANTINFO,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.TenantInfo)
  ))
_sym_db.RegisterMessage(TenantInfo)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

AddGatewayRequest = _reflection.GeneratedProtocolMessageType('AddGatewayRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDGATEWAYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddGatewayRequest)
  ))
_sym_db.RegisterMessage(AddGatewayRequest)

AddGatewayResponse = _reflection.GeneratedProtocolMessageType('AddGatewayResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDGATEWAYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddGatewayResponse)
  ))
_sym_db.RegisterMessage(AddGatewayResponse)

DeleteGatewayRequest = _reflection.GeneratedProtocolMessageType('DeleteGatewayRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEGATEWAYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteGatewayRequest)
  ))
_sym_db.RegisterMessage(DeleteGatewayRequest)

DeleteGatewayResponse = _reflection.GeneratedProtocolMessageType('DeleteGatewayResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETEGATEWAYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteGatewayResponse)
  ))
_sym_db.RegisterMessage(DeleteGatewayResponse)

CreateCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATEREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CreateCertificateRequest)
  ))
_sym_db.RegisterMessage(CreateCertificateRequest)

CreateCertificateResponse = _reflection.GeneratedProtocolMessageType('CreateCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATERESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CreateCertificateResponse)
  ))
_sym_db.RegisterMessage(CreateCertificateResponse)

GetIssuanceHistoryRequest = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetIssuanceHistoryRequest)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryRequest)

CertificateInfo = _reflection.GeneratedProtocolMessageType('CertificateInfo', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEINFO,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.CertificateInfo)
  ))
_sym_db.RegisterMessage(CertificateInfo)

GetIssuanceHistoryResponse = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetIssuanceHistoryResponse)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryResponse)

GetCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistRequest)

GetCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.GetCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistResponse)

AddCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistRequest)

AddCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.AddCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistResponse)

DeleteCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTREQUEST,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistRequest)

DeleteCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'tenant_pb2'
  # @@protoc_insertion_point(class_scope:tenant.DeleteCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistResponse)


DESCRIPTOR._options = None

_TENANT = _descriptor.ServiceDescriptor(
  name='Tenant',
  full_name='tenant.Tenant',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1318,
  serialized_end=2202,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='tenant.Tenant.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='tenant.Tenant.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='tenant.Tenant.Add',
    index=2,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='tenant.Tenant.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddGateway',
    full_name='tenant.Tenant.AddGateway',
    index=4,
    containing_service=None,
    input_type=_ADDGATEWAYREQUEST,
    output_type=_ADDGATEWAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteGateway',
    full_name='tenant.Tenant.DeleteGateway',
    index=5,
    containing_service=None,
    input_type=_DELETEGATEWAYREQUEST,
    output_type=_DELETEGATEWAYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCertificate',
    full_name='tenant.Tenant.CreateCertificate',
    index=6,
    containing_service=None,
    input_type=_CREATECERTIFICATEREQUEST,
    output_type=_CREATECERTIFICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIssuanceHistory',
    full_name='tenant.Tenant.GetIssuanceHistory',
    index=7,
    containing_service=None,
    input_type=_GETISSUANCEHISTORYREQUEST,
    output_type=_GETISSUANCEHISTORYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCertificateBlacklist',
    full_name='tenant.Tenant.GetCertificateBlacklist',
    index=8,
    containing_service=None,
    input_type=_GETCERTIFICATEBLACKLISTREQUEST,
    output_type=_GETCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddCertificateBlacklist',
    full_name='tenant.Tenant.AddCertificateBlacklist',
    index=9,
    containing_service=None,
    input_type=_ADDCERTIFICATEBLACKLISTREQUEST,
    output_type=_ADDCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCertificateBlacklist',
    full_name='tenant.Tenant.DeleteCertificateBlacklist',
    index=10,
    containing_service=None,
    input_type=_DELETECERTIFICATEBLACKLISTREQUEST,
    output_type=_DELETECERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENANT)

DESCRIPTOR.services_by_name['Tenant'] = _TENANT

# @@protoc_insertion_point(module_scope)
